# -*- coding: UTF-8 -*-
import os, shutil
from django.test import TestCase
from secrets.models import Git, Secret
import Molho.settings as settings

class GitTest(TestCase):
    def setUp(self):
        os.chdir("/tmp")
        os.system("git init -q --bare teste_molho_bare")
        os.system("git clone -q teste_molho_bare teste_molho_orig")
        os.chdir("/tmp/teste_molho_orig")
        os.system("touch teste")
        os.system("git add teste")
        os.system("git commit -q -a -m 'teste'")
        os.system("git remote add origin /tmp/teste_molho_bare/")
        os.system("git push -q origin master")
        os.chdir("/tmp/")
        settings.keys_path = "/tmp/tmp_molho"
        settings.git_path = "/tmp/tmp_molho"
        self.git = Git("/tmp/teste_molho_bare")

    def test_save_state(self):
        os.chdir(settings.keys_path)
        os.system("touch arquivo1")
        self.git.save_state("arquivo1")
        os.chdir("/tmp/")
        os.system("git clone -q teste_molho_bare teste_molho_alt")
        self.assertTrue(os.path.exists("/tmp/teste_molho_alt/arquivo1"))

    def test_update(self):
        os.chdir("/tmp")
        os.system("git clone -q teste_molho_bare teste_molho_alt")
        os.chdir("teste_molho_alt")
        os.system("touch arquivo6")
        os.system("git add arquivo6")
        os.system("git remote add origin /tmp/teste_molho_bare/")
        os.system("git push -q origin master")
        os.chdir(settings.keys_path)
        self.git.update()
        self.assertTrue(os.path.exists("/tmp/teste_molho_alt/arquivo6"))

    def test_push(self):
        os.chdir(settings.keys_path)
        os.system("touch arquivo1")
        os.system("git add arquivo1")
        os.system("git commit -q -a -m 'test'")
        self.git.push()
        os.chdir("/tmp/")
        os.system("git clone -q teste_molho_bare teste_molho_alt")
        self.assertTrue(os.path.exists("/tmp/teste_molho_alt/arquivo1"))


    def tearDown(self):
        os.system("rm -rf /tmp/teste_molho_orig")
        os.system("rm -rf /tmp/teste_molho_bare")
        os.system("rm -rf /tmp/teste_molho_alt")
        os.system("rm -rf %s" % settings.keys_path)

class SecretTestCase(TestCase):
    def setUp(self):
        os.chdir("/tmp")
        os.system("git init --bare teste_molho_bare")
        settings.keys_path="/tmp/teste_molho_orig"
        settings.git_path="/tmp/teste_molho_orig"
        self.secret = Secret(Git("/tmp/teste_molho_bare"), "teste")
        os.system("git clone teste_molho_bare teste_molho_orig")
        open("/tmp/teste_molho_orig/teste","w").write("{'name':'teste','content':''}")
        open("/tmp/teste_molho_orig/teste2","w").write("{'name':'teste2','content':''}")
        open("/tmp/teste_molho_orig/teste3","w").write("{'name':'teste3','content':''}")
        os.chdir("/tmp/teste_molho_orig")
        os.system("git add teste teste2 teste3")
        os.system("git commit -a -m 'teste'")
        os.system("git remote add origin /tmp/teste_molho_bare/")
        os.system("git push origin master")
#        

    def testGetContent(self):
        self.assertEquals(self.secret.get_content(), "{'name':'teste','content':''}")

    def testSetContent(self):
        old_data = self.secret.get_content()
        self.secret.set_content("teste")
        self.assertEqual(self.secret.get_content(), "teste")
        self.assertNotEqual(old_data, self.secret.get_content())

    def testContentProperty(self):
        old_data = self.secret.content
        self.secret.content = "teste"
        self.assertEquals(self.secret.content, "teste")
        self.assertNotEqual(old_data, self.secret.content) 	

    def testTemplateEntry(self):
        self.secret.template_entry()
        self.assertEquals(self.secret.content, "{'name':'%s','content':'%s'}" %(self.secret.name, ''))
	
	
    def tearDown(self):
    
        os.system("rm -rf /tmp/teste_molho_orig")
        os.system("rm -rf /tmp/teste_molho_bare")
        os.system("rm -rf /tmp/teste_molho_alt")
        os.system("rm -rf %s" % settings.keys_path)


